Crate tari_script

Crate tari_script 

Macros

inputs
script

Structs

CheckSigHashDomain
A hashing domain instance
ExecutionStack
ScriptContext
Contextual data for use in Tari scripts. The context will typically be unambiguously and deterministically populated by nodes that are executing the script.
TariScript

Enums

Opcode
OpcodeVersion
ScriptError
StackItem

Functions

push_pubkey_script
The standard payment script to be used for one-sided payment to public addresses
slice_to_boxed_hash
Convert a slice into a Boxed HashValue
slice_to_boxed_message
Convert a slice into a Boxed Message
slice_to_hash
Convert a slice into a HashValue.

Type Aliases

CheckSigSchnorrSignature
The type used for CheckSig, CheckMultiSig, and related opcodes’ signatures
CompressedCheckSigSchnorrSignature
HashValue
Message
ScalarValue
ScriptOpcodes
The sized vector of opcodes that make up a script