Macros
Structs
- Check
SigHash Domain - A hashing domain instance
- Execution
Stack - Script
Context - Contextual data for use in Tari scripts. The context will typically be unambiguously and deterministically populated by nodes that are executing the script.
- Tari
Script
Enums
Functions
- push_
pubkey_ script - The standard payment script to be used for one-sided payment to public addresses
- slice_
to_ boxed_ hash - Convert a slice into a Boxed HashValue
- slice_
to_ boxed_ message - Convert a slice into a Boxed Message
- slice_
to_ hash - Convert a slice into a HashValue.
Type Aliases
- Check
SigSchnorr Signature - The type used for
CheckSig,CheckMultiSig, and related opcodes’ signatures - Compressed
Check SigSchnorr Signature - Hash
Value - Message
- Scalar
Value - Script
Opcodes - The sized vector of opcodes that make up a script